#!/usr/bin/env python
# -*- coding: utf-8 -*-
# created at 14.05.2011

# This software is distributed under the BSD license.
# http://www.opensource.org/licenses/bsd-license.php 
# Copyright © 2011, Oleg Churkin

"""
Distutils setup file.
"""

__version__ = "0.2"

from distutils.core import setup

# Hack for Python 3 to tell distutils to run 2to3 against the files
# copied in the build directory before installing.
# Reference: http://wiki.python.org/moin/PortingPythonToPy3k
try:
    from distutils.command.build_py import build_py_2to3 as build_py #IGNORE:E0611
except ImportError:
    from distutils.command.build_py import build_py


def main():
    setup(
        name="easylogger",
        packages=["easylogger"],
        version=__version__,
        description="Module provides some advanced features for original Python logging.",
        author="Oleg Churkin",
        author_email="bahusoff@gmail.com",
        url="http://code.google.com/p/easy-logger/",
        keywords=["logging"],
        cmdclass={'build_py': build_py},  # Python 3.X
        platforms="Platform Independent",
        license="License :: OSI Approved :: BSD License",    
        classifiers=[
            "Development Status :: 5 - Production/Stable",
            "Environment :: Console",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows :: Windows NT/2000",
            "Operating System :: POSIX :: Linux",
            "Operating System :: OS Independent",
            "Programming Language :: Python",
            "Programming Language :: Python :: 2.6",
            "Programming Language :: Python :: 2.7",
            "Programming Language :: Python :: 3",
            "Topic :: System :: Logging",
            "Topic :: System :: Systems Administration",
            "Topic :: Software Development :: Libraries :: Python Modules",
            "Intended Audience :: Developers",
            "Intended Audience :: System Administrators",
            "License :: OSI Approved :: BSD License",
            ],
        long_description="""\
Easylogger
==========

Easylogger is a Python package which wraps aspects of original `logging`
module in simple and Pythonic way. You can use all power of the original package
with the new facilities side-by-side.

The key features of current version of 'easylogging' package are:

* Easy to start logging without configuring anything;
* Provided decorator-mode to log function or method call including its doc-string;
* Imitate and replace stdout and stderr streams in order to redirect `print` messages to required logging handlers;
* Alternative message formatting system (like `print` does);
    """
    )
    
if __name__ == '__main__':
    main()
        